Federation class
Represents a federation of multiple backend metastores.
- Inheritance
-
- Object
- GeneratedMessage
- Federation
Constructors
-
Federation({String? name, Timestamp? createTime, Timestamp? updateTime, Map<
String, String> ? labels, String? version, Map<int, BackendMetastore> ? backendMetastores, String? endpointUri, Federation_State? state, String? stateMessage, String? uid}) -
factory
-
Federation.fromBuffer(List<
int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY]) -
factory
- Federation.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
-
backendMetastores
→ Map<
int, BackendMetastore> -
A map from
BackendMetastorerank toBackendMetastores from which the federation service serves metadata at query time. The map key represents the order in whichBackendMetastores should be evaluated to resolve database names at query time and should be greater than or equal to zero. ABackendMetastorewith a lower number will be evaluated before aBackendMetastorewith a higher number.no setter - createTime ↔ Timestamp
-
Output only. The time when the metastore federation was created.
getter/setter pair
- endpointUri ↔ String
-
Output only. The federation endpoint.
getter/setter pair
- eventPlugin → EventPlugin?
-
Subclasses can override this getter to be notified of changes
to protobuf fields.
no setterinherited
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setteroverride
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited -
labels
→ Map<
String, String> -
User-defined labels for the metastore federation.
no setter
- name ↔ String
-
Immutable. The relative resource name of the federation, of the
form:
projects/{project_number}/locations/{location_id}/federations/{federation_id}`.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ Federation_State
-
Output only. The current state of the federation.
getter/setter pair
- stateMessage ↔ String
-
Output only. Additional information about the current state of the
metastore federation, if available.
getter/setter pair
- uid ↔ String
-
Output only. The globally unique resource identifier of the metastore
federation.
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- updateTime ↔ Timestamp
-
Output only. The time when the metastore federation was last updated.
getter/setter pair
- version ↔ String
-
Immutable. The Apache Hive metastore version of the federation. All backend
metastore versions must be compatible with the federation version.
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearCreateTime(
) → void -
clearEndpointUri(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearName(
) → void -
clearState(
) → void -
clearStateMessage(
) → void -
clearUid(
) → void -
clearUpdateTime(
) → void -
clearVersion(
) → void -
clone(
) → Federation -
Creates a deep copy of the fields in this message.
(The generated code uses mergeFromMessage.)
override
-
copyWith(
void updates(Federation)) → Federation -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → Federation -
Creates an empty instance of the same message type as this.
override
-
createMapField<
K, V> (int tagNumber, MapFieldInfo< K, V> fi) → Map<K, V> -
Creates a Map representing a map field.
inherited
-
createRepeatedField<
T> (int tagNumber, FieldInfo< T> fi) → List<T> -
Creates List implementing a mutable repeated field.
inherited
-
ensureCreateTime(
) → Timestamp -
ensureUpdateTime(
) → Timestamp -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasCreateTime(
) → bool -
hasEndpointUri(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasName(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasState(
) → bool -
hasStateMessage(
) → bool -
hasUid(
) → bool -
hasUpdateTime(
) → bool -
hasVersion(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → Federation -
createRepeated(
) → PbList< Federation> -
getDefault(
) → Federation