copyWith method

  1. @Deprecated('Using this can add significant overhead to your binary. ' 'Use [GeneratedMessageGenericExtensions.rebuild] instead. ' 'Will be removed in next major version')
ServiceConnectionMapCreatedEvent copyWith(
  1. void updates(
    1. ServiceConnectionMapCreatedEvent
    )
)
override

Apply updates to a copy of this message.

Makes a writable shallow copy of this message, applies the updates to it, and marks the copy read-only before returning it.

Implementation

@$core.Deprecated(
'Using this can add significant overhead to your binary. '
'Use [GeneratedMessageGenericExtensions.rebuild] instead. '
'Will be removed in next major version')
ServiceConnectionMapCreatedEvent copyWith(void Function(ServiceConnectionMapCreatedEvent) updates) => super.copyWith((message) => updates(message as ServiceConnectionMapCreatedEvent)) as ServiceConnectionMapCreatedEvent;