copyWith method

  1. @Deprecated('Using this can add significant overhead to your binary. ' 'Use [GeneratedMessageGenericExtensions.rebuild] instead. ' 'Will be removed in next major version')
CustomClass_ClassItem copyWith(
  1. void updates(
    1. CustomClass_ClassItem
    )
)
override

Apply updates to a copy of this message.

Makes a writable shallow copy of this message, applies the updates to it, and marks the copy read-only before returning it.

Implementation

@$core.Deprecated(
'Using this can add significant overhead to your binary. '
'Use [GeneratedMessageGenericExtensions.rebuild] instead. '
'Will be removed in next major version')
CustomClass_ClassItem copyWith(void Function(CustomClass_ClassItem) updates) => super.copyWith((message) => updates(message as CustomClass_ClassItem)) as CustomClass_ClassItem;